;;; db-nosetf.el --- EDB programming interface that does not use setf

;; Copyright (C) 2004,2005 Thien-Thi Nguyen

;; EDB is distributed under the terms of the GNU General Public License.

;; EDB is distributed in the hope that it will be useful, but WITHOUT
;; ANY WARRANTY.  No author or distributor accepts responsibility to anyone
;; for the consequences of using it or for whether it serves any particular
;; purpose or works at all, unless he says so in writing.  Refer to the GNU
;; General Public License for full details.

;; Everyone is granted permission to copy, modify and redistribute EDB, but
;; only under the conditions described in the GNU General Public License.  A
;; copy of this license is supposed to have been given to you along with EDB
;; so you can know your rights and responsibilities.  It should be in a file
;; named COPYING.  If not, write to the Free Software Foundation, Inc., 675
;; Mass Ave, Cambridge, MA 02139, USA for a copy.  Among other things, the
;; copyright notice and this notice must be preserved on all copies.

;;; Commentary:

;; Internally, EDB uses `defstruct' which normally provides for each slot a
;; TYPE-SLOT function which is setf-able.  Thus:
;;
;;        (TYPE-SLOT object)            ; getter
;;  (setf (TYPE-SLOT object) value)     ; setter
;;
;; EDB 1.x defines aliases for the setter of the form:
;;
;;  (TYPE-set-SLOT object value)
;;
;; This file provides all those aliases, which although unused internally,
;; are documented in the EDB Manual, and will continue to be supported for
;; the 1.x series.  2.x is another matter, however...

;;; Code:

(defsubst displayspec-set-record-index (ds val) (setf (displayspec-record-index ds) val))
(defsubst displayspec-set-indent (ds val) (setf (displayspec-indent ds) val))
(defsubst displayspec-set-min-width (ds val) (setf (displayspec-min-width ds) val))
(defsubst displayspec-set-max-width (ds val) (setf (displayspec-max-width ds) val))
(defsubst displayspec-set-min-height (ds val) (setf (displayspec-min-height ds) val))
(defsubst displayspec-set-max-height (ds val) (setf (displayspec-max-height ds) val))
(defsubst displayspec-set-min-bytes (ds val) (setf (displayspec-min-bytes ds) val))
(defsubst displayspec-set-max-bytes (ds val) (setf (displayspec-max-bytes ds) val))
(defsubst displayspec-set-truncation-display-action (ds val) (setf (displayspec-truncation-display-action ds) val))
(defsubst displayspec-set-padding-action (ds val) (setf (displayspec-padding-action ds) val))
(defsubst displayspec-set-actual->display (ds val) (setf (displayspec-actual->display ds) val))
(defsubst displayspec-set-display->actual (ds val) (setf (displayspec-display->actual ds) val))
(defsubst displayspec-set-match-actual->display (ds val) (setf (displayspec-match-actual->display ds) val))
(defsubst displayspec-set-match-display->actual (ds val) (setf (displayspec-match-display->actual ds) val))
(defsubst displayspec-set-truncation-editing-action (ds val) (setf (displayspec-truncation-editing-action ds) val))
(defsubst displayspec-set-reachablep (ds val) (setf (displayspec-reachablep ds) val))
(defsubst database-set-print-name (db val) (setf (database-print-name db) val))
(defsubst database-set-first-link (db val) (setf (database-first-link db) val))
(defsubst database-set-no-of-records (db val) (setf (database-no-of-records db) val))
(defsubst database-set-file (db val) (setf (database-file db) val))
(defsubst database-set-file-local-variables (db val) (setf (database-file-local-variables db) val))
(defsubst database-set-aux-file (db val) (setf (database-aux-file db) val))
(defsubst database-set-data-display-buffers (db val) (setf (database-data-display-buffers db) val))
(defsubst database-set-default-format-file (db val) (setf (database-default-format-file db) val))
(defsubst database-set-hide-functions (db val) (setf (database-hide-functions db) val))
(defsubst database-set-no-of-fields (db val) (setf (database-no-of-fields db) val))
(defsubst database-set-fieldnames (db val) (setf (database-fieldnames db) val))
(defsubst database-set-fieldname-alist (db val) (setf (database-fieldname-alist db) val))
(defsubst database-set-recordfieldspecs (db val) (setf (database-recordfieldspecs db) val))
(defsubst database-set-field-priorities (db val) (setf (database-field-priorities db) val))
(defsubst database-set-hidden-to-end-p (db val) (setf (database-hidden-to-end-p db) val))
(defsubst database-set-internal-file-layout-p (db val) (setf (database-internal-file-layout-p db) val))
(defsubst database-set-record-sepinfo (db val) (setf (database-record-sepinfo db) val))
(defsubst database-set-field-sepinfo (db val) (setf (database-field-sepinfo db) val))
(defsubst database-set-alternative-sepinfo (db val) (setf (database-alternative-sepinfo db) val))
(defsubst database-set-read-record-from-region (db val) (setf (database-read-record-from-region db) val))
(defsubst database-set-write-region-from-record (db val) (setf (database-write-region-from-record db) val))
(defsubst database-set-sub-fieldsep-string (db val) (setf (database-sub-fieldsep-string db) val))
(defsubst database-set-sub-recordsep-string (db val) (setf (database-sub-recordsep-string db) val))
(defsubst database-set-substitutions (db val) (setf (database-substitutions db) val))
(defsubst database-set-modifiable-p (db val) (setf (database-modifiable-p db) val))
(defsubst database-set-locals (db val) (setf (database-locals db) val))
(defsubst link-set-prev (l val) (setf (link-prev l) val))
(defsubst link-set-next (l val) (setf (link-next l) val))
(defsubst link-set-markedp (l val) (setf (link-markedp l) val))
(defsubst link-set-hiddenp (l val) (setf (link-hiddenp l) val))
(defsubst link-set-summary (l val) (setf (link-summary l) val))
(defsubst recordfieldspec-set-type (rs val) (setf (recordfieldspec-type rs) val))
(defsubst recordfieldspec-set-default-value (rs val) (setf (recordfieldspec-default-value rs) val))
(defsubst recordfieldspec-set-common-form-function (rs val) (setf (recordfieldspec-common-form-function rs) val))
(defsubst recordfieldspec-set-merge-function (rs val) (setf (recordfieldspec-merge-function rs) val))
(defsubst recordfieldspec-set-order-fn (rs val) (setf (recordfieldspec-order-fn rs) val))
(defsubst recordfieldspec-set-sort-fn (rs val) (setf (recordfieldspec-sort-fn rs) val))
(defsubst recordfieldspec-set-match-function (rs val) (setf (recordfieldspec-match-function rs) val))
(defsubst recordfieldspec-set-help-info (rs val) (setf (recordfieldspec-help-info rs) val))
(defsubst recordfieldspec-set-actual->stored (rs val) (setf (recordfieldspec-actual->stored rs) val))
(defsubst recordfieldspec-set-stored->actual (rs val) (setf (recordfieldspec-stored->actual rs) val))
(defsubst recordfieldspec-set-change-hook (rs val) (setf (recordfieldspec-change-hook rs) val))
(defsubst recordfieldspec-set-constraint-function (rs val) (setf (recordfieldspec-constraint-function rs) val))
(defsubst sepinfo-set-pre-first-string (si val) (setf (sepinfo-pre-first-string si) val))
(defsubst sepinfo-set-pre-first-regexp (si val) (setf (sepinfo-pre-first-regexp si) val))
(defsubst sepinfo-set-pre-first-regexp-submatch (si val) (setf (sepinfo-pre-first-regexp-submatch si) val))
(defsubst sepinfo-set-sep-string (si val) (setf (sepinfo-sep-string si) val))
(defsubst sepinfo-set-sep-regexp (si val) (setf (sepinfo-sep-regexp si) val))
(defsubst sepinfo-set-sep-regexp-submatch (si val) (setf (sepinfo-sep-regexp-submatch si) val))
(defsubst sepinfo-set-sep-function (si val) (setf (sepinfo-sep-function si) val))
(defsubst sepinfo-set-post-last-string (si val) (setf (sepinfo-post-last-string si) val))
(defsubst sepinfo-set-post-last-regexp (si val) (setf (sepinfo-post-last-regexp si) val))
(defsubst sepinfo-set-post-last-regexp-submatch (si val) (setf (sepinfo-post-last-regexp-submatch si) val))

;; Order-function and sort-function pseudo-slots
(defsubst recordfieldspec-set-order-function (rs val) (setf (recordfieldspec-order-fn rs) val))
(defsubst recordfieldspec-set-sort-function (rs val) (setf (recordfieldspec-sort-fn rs) val))

(provide 'db-nosetf)

;;; db-nosetf.el ends here
