;;; edb-t-places-usuk.el

;; Copyright (C) 2005 Thien-Thi Nguyen

;; Authors: Michael Ernst <mernst@theory.lcs.mit.edu> and Alan K. Stebbens

;; EDB is distributed under the terms of the GNU General Public License.

;; EDB is distributed in the hope that it will be useful, but WITHOUT
;; ANY WARRANTY.  No author or distributor accepts responsibility to anyone
;; for the consequences of using it or for whether it serves any particular
;; purpose or works at all, unless he says so in writing.  Refer to the GNU
;; General Public License for full details.

;; Everyone is granted permission to copy, modify and redistribute EDB, but
;; only under the conditions described in the GNU General Public License.  A
;; copy of this license is supposed to have been given to you along with EDB
;; so you can know your rights and responsibilities.  It should be in a file
;; named COPYING.  If not, write to the Free Software Foundation, Inc., 675
;; Mass Ave, Cambridge, MA 02139, USA for a copy.  Among other things, the
;; copyright notice and this notice must be preserved on all copies.

;;; Commentary:

;; Places in the US/UK
;;
;; These variables and functions used to be in db-types.el,
;; without the "edb-t-places-usuk:" prefix.

;;; Code:

(defvar edb-t-places-usuk:UK-postal-code-regexp
  "[A-Z][0-9][A-Z] ?[0-9][A-Z][0-9]")

(defvar edb-t-places-usuk:zip-code-regexp
  "[0-9][0-9][0-9][0-9][0-9]\\(-?[0-9][0-9][0-9][0-9]\\)?")

(defvar edb-t-places-usuk:postal-code-regexp
  (mapconcat
   'identity
   (list
    ;; US zip code
    edb-t-places-usuk:zip-code-regexp
    ;; UK postal code
    edb-t-places-usuk:UK-postal-code-regexp
    ;; other
    "[0-9][0-9A-Z]*")
   "\\|"))

(defsubst edb-t-places-usuk:postal-code-p (s)
  (string-match edb-t-places-usuk:postal-code-regexp s))

;; Full state-alist and associated functions added by
;; Alan Stebbens, UCSB, Sep 18 '92.

(defvar edb-t-places-usuk:state-alist
  '(("AK" . "Alaska")
    ("AL" . "Alabama")
    ("AR" . "Arkansas")
    ("AZ" . "Arizona")
    ("CA" . "California")
    ("CO" . "Colorado")
    ("CT" . "Conneticut")
    ("DC" . "District of Columbia")
    ("DE" . "Deleware")
    ("FL" . "Florida")
    ("GA" . "Georgia")
    ("GU" . "Guam")
    ("HI" . "Hawaii")
    ("ID" . "Idaho")
    ("IL" . "Illinois")
    ("IN" . "Indiana")
    ("IA" . "Iowa")
    ("KS" . "Kansas")
    ("KY" . "Kentucky")
    ("LA" . "Louisiana")
    ("MA" . "Massachusetts")
    ("MD" . "Maryland")
    ("ME" . "Maine")
    ("MI" . "Michigan")
    ("MN" . "Minnessota")
    ("MS" . "Mississippi")
    ("MO" . "Missouri")
    ("MT" . "Montana")
    ("NE" . "Nebraska")
    ("NH" . "New Hampshire")
    ("NC" . "North Carolina")
    ("ND" . "North Dakota")
    ("NJ" . "New Jersey")
    ("NM" . "New Mexico")
    ("NV" . "Nevada")
    ("NY" . "New York")
    ("OH" . "Ohio")
    ("OK" . "Oklahoma")
    ("OR" . "Oregon")
    ("PA" . "Pennsylvania")
    ("PR" . "Puerto Rico")
    ("RI" . "Rhode Island")
    ("SC" . "South Carolina")
    ("SD" . "South Dakota")
    ("TX" . "Texas")
    ("TN" . "Tennessee")
    ("UT" . "Utah")
    ("VA" . "Virginia")
    ("VT" . "Vermont")
    ("WA" . "Washington")
    ("WI" . "Wisconson")
    ("WV" . "West Virginia")
    ("WY" . "Wyoming"))
  "An alist of ABBREV and FULLNAME of each of the United States, and its
territories.  Used by \"edb-t-places-usuk:full-state-name\" and
\"edb-t-places-usuk:abbreviate-state\".")

(defun edb-t-places-usuk:statep (obj)
  "Return non-nil if OBJ is a valid state abbreviation."
  (when (stringp obj) (edb-t-places-usuk:full-state-name obj)))

(defun edb-t-places-usuk:full-state-name (abbrev)
  "Return the full state name for ABBREV, or nil if not found."
  (and (= 2 (length abbrev))
       (cdr (assoc (upcase abbrev) edb-t-places-usuk:state-alist))))

(defun edb-t-places-usuk:abbreviate-state (state)
  "Return the postal abbreviation for STATE, or nil if not found."
  (car (rassoc (capitalize state) edb-t-places-usuk:state-alist)))


(provide 'edb-t-places-usuk)

;;; edb-t-places-usuk.el ends here
